clear all; close all; clc;
NumberOfCycles = [405,519,537,446,624,566,1154,492,446,524,516]; %Number of cycles from biological data
NumberOfPoints = 288000;

for k = 1:length(NumberOfCycles)
    
    disp(k);
    
    deltaT = 1/(NumberOfPoints/NumberOfCycles(k));
    
    %% Periodic
    t = 0:deltaT:NumberOfCycles(k)-deltaT;
    p = 0.25*sin(t)+0.75;
    periodic = p.*sin(2*pi*t);
    peaks = length(findpeaks(periodic));
    
    %% Random
    random = 0;
    t1 = 0:deltaT:1;
    while length(random) < length(periodic)
        a = 0.5; b = 1;
        rA = (b-a).*rand(1,1) + a;
        random = [random rA*sin(2*pi*t1)];
    end
    random = random(1:length(periodic));
    
    %% Chaotic
    chaotic = []; i = 1;
    cA = pinkNoise(round(NumberOfCycles(k)+10));
    cA0_1 = ( cA - min(cA)+0.1 ) / ( max(cA)+0.1 - min(cA)+0.1 );
    cA0_1 = cA0_1/2+0.5;
    t2 = 0:deltaT:1;
    while length(chaotic) < length(periodic)
        try
            chaotic = [chaotic cA0_1(i).*sin(2*pi*t2)];
            i = i+1;
        catch
            break;
        end
    end
    try
        chaotic = chaotic(1:length(periodic));
    end
    
    %% Smooth transitions
    random_b = smooth(random,'moving',10);
    chaotic_b = smooth(chaotic,'moving',10);
    
    %% Store to mat
    Input.(['Periodic_Amplitude_t' num2str(k)]) = periodic;
    Input.(['Random_Amplitude_t' num2str(k)]) = random;
    Input.(['Chaotic_Amplitude_t' num2str(k)]) = chaotic;
    
    % % %     %% Plot
    % % %     ax(1) = subplot(3,1,1); plot(periodic_1); hold on; plot(periodic);
    % % %     ax(2) = subplot(3,1,2); plot(random_1_b); hold on; plot(random_b);
    % % %     ax(3) = subplot(3,1,3); plot(chaotic_1_b); hold on; plot(chaotic_b);
    % % %     linkaxes(ax,'x');
    
    % % %     %% Write files
    % % %     dlmwrite(['Periodic_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Amplitude' '.txt'],[periodic_1;periodic]');
    % % %     dlmwrite(['Random_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Amplitude_' num2str(k) '.txt'],[random_1;random]');
    % % %     dlmwrite(['Chaotic_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Amplitude_' num2str(k) '.txt'],[chaotic_1;chaotic]');
    
    
end

save('Amplitude.mat','Input');