clear all; close all; clc;
NumberOfCycles = [405,519,537,446,624,566,1154,492,446,524,516]; %Number of cycles from biological data
NumberOfPoints = 288000;

for k = 1:length(NumberOfCycles)
    
    disp(k);
    
    deltaT = 1/(NumberOfPoints/NumberOfCycles(k));
    
    %% Periodic
    t = 0:deltaT:NumberOfCycles(k)-deltaT;
    p = 0.25*sin(t)+0.75;
    periodic = p.*sin(2*pi*t);
    
    peaks = length(findpeaks(periodic));
    
    %% Random
    random_range = [76 126];
    holder = 0;
    while abs(holder - peaks) > 1
        random = 0;
        while length(random) < length(periodic)
            r = randi(random_range,1,1)/100*2*pi;
            
            a = 0.5; b = 1;
            rA = (b-a).*rand(1,1) + a;
            % % %             rA = rand(1,1);
            
            t1 = 0:deltaT:(2*pi)/r-deltaT;
            % % %             random = [random sin(t1*r/ratio(2))];
            random = [random rA*sin(t1*r)];
        end
        random = random(1:length(periodic));
        holder = length(findpeaks(random));
    end
    
    %% Chaotic
    holder  = 0;
    while abs(holder - peaks) > 1
        chaotic = []; i = 1;
        c = pinkNoise(round(NumberOfCycles(k)+2)); shift_c = min(c);
        c = (c - shift_c+1)*2*pi/10;
        c = c-mean(c)+2*pi+deltaT;
        cA = pinkNoise(round(NumberOfCycles(k)+2));
        cA0_1 = ( cA - min(cA)+0.1 ) / ( max(cA)+0.1 - min(cA)+0.1 );
        cA0_1 = cA0_1/2+0.5;
        while length(chaotic) < length(periodic)
            try
                t2 = 0:deltaT:(2*pi)/c(i)-deltaT;
                chaotic = [chaotic cA0_1(i)*sin(t2*c(i))];
                i = i+1;
            catch
                break;
            end
        end
        try
            chaotic = chaotic(1:length(periodic));
            holder = length(findpeaks(chaotic));
        end
    end
    
    %% Smooth transitions
    random_b = smooth(random,'moving',10);
    chaotic_b = smooth(chaotic,'moving',10);
    
    %% Store to mat
    Input.(['Periodic_PeriodAndAmplitude_t' num2str(k)]) = periodic;
    Input.(['Random_PeriodAndAmplitude_t' num2str(k)]) = random;
    Input.(['Chaotic_PeriodAndAmplitude_t' num2str(k)]) = chaotic;
    
        %% Plot
        ax(1) = subplot(3,1,1); plot(periodic);
        ax(2) = subplot(3,1,2); plot(random_b);
        ax(3) = subplot(3,1,3); plot(chaotic_b);
        linkaxes(ax,'x');
    
    % % %     %% Write files
    % % %     dlmwrite(['Periodic_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Both' '.txt'],[periodic_1;periodic]');
    % % %     dlmwrite(['Random_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Both_' num2str(k) '.txt'],[random_1;random]');
    % % %     dlmwrite(['Chaotic_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Both_' num2str(k) '.txt'],[chaotic_1;chaotic]');
    
end

save('PeriodAndAmplitude.mat','Input');