clear all; close all; clc;
NumberOfCycles = [405,519,537,446,624,566,1154,492,446,524,516]; %Number of cycles from biological data
NumberOfPoints = 288000;

for k = 1:length(NumberOfCycles)
    
    disp(k);
    
    deltaT = 1/(NumberOfPoints/NumberOfCycles(k));
    
    %% Periodic
    t = 0:deltaT:NumberOfCycles(k)-deltaT;
    periodic = sin(2*pi*t);
    peaks = length(findpeaks(periodic));
    
    %% Random
    random_range = [76 126];
    holder = 0;
    while abs(holder - peaks) > 1
        random = [];
        while length(random) < length(periodic)
            r = randi(random_range,1,1)/100*2*pi;
            t1 = 0:deltaT:(2*pi)/r-deltaT;
            random = [random sin(t1*r)];
        end
        random = random(1:length(periodic));
        holder = length(findpeaks(random));
    end
    
    %% Chaotic
    holder  = 0;
    while abs(holder - peaks) > 1
        chaotic = []; i = 1;
        c = pinkNoise(round(NumberOfCycles(k))+2); shift_c = min(c);
        c = (c - shift_c+1)*2*pi/10;
        c = c-mean(c)+2*pi+deltaT;
        while length(chaotic) < length(periodic)
            try
                t2 = 0:deltaT:(2*pi)/c(i)-deltaT;
                chaotic = [chaotic sin(t2*c(i))];
                i = i+1;
            catch
                break;
            end
        end
        try
            chaotic = chaotic(1:length(periodic));
            holder = length(findpeaks(chaotic));
        end
    end
    
    %% Smooth transitions
    random_b = smooth(random,'moving',10);
    chaotic_b = smooth(chaotic,'moving',10);
    
    %% Store to mat
    Input.(['Periodic_Period_t' num2str(k)]) = periodic;
    Input.(['Random_Period_t' num2str(k)]) = random;
    Input.(['Chaotic_Period_t' num2str(k)]) = chaotic;
    
    % % %         %% Plot
    % % %         ax(1) = subplot(3,1,1); plot(periodic_1); hold on; plot(periodic);
    % % %         ax(2) = subplot(3,1,2); plot(random_1_b); hold on; plot(random_b);
    % % %         ax(3) = subplot(3,1,3); plot(chaotic_1_b); hold on; plot(chaotic_b);
    % % %         linkaxes(ax,'x');
    
    % % %         %% Write files
    % % %         dlmwrite(['Periodic_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Period' '.txt'],[periodic_1;periodic]');
    % % %         dlmwrite(['Random_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Period_' num2str(k) '.txt'],[random_1;random]');
    % % %         dlmwrite(['Chaotic_' num2str(ratioHolder(1)) 'to' num2str(ratioHolder(2)) '_' condition '_Period_' num2str(k) '.txt'],[chaotic_1;chaotic]');
   
    
end

save('Period.mat','Input');